<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu" sourcelanguage="en">
  <context>
    <name>CmdRobotAddToolShape</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="+215"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Add tool</source>
      <translation>Szerszám hozzáadása</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Add a tool shape to the robot</source>
      <translation>Formázó szerszám hozzáadása a robothoz</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+158"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Place robot...</source>
      <translation>Robot elhelyezése...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Place a robot (experimental!)</source>
      <translation>Robot helye (kísérleti!)</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotCreateTrajectory</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="+61"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create trajectory</source>
      <translation>Útvonal létrehozása</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a new empty trajectory </source>
      <translation>Új üres útvonal létrehozása </translation>
    </message>
  </context>
  <context>
    <name>CmdRobotEdge2Trac</name>
    <message>
      <location line="+257"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Edge to Trajectory...</source>
      <translation>Él az útvonalhoz...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Generate a Trajectory from a set of edges</source>
      <translation>Útvonal létrehozása élek alapján</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotExportKukaCompact</name>
    <message>
      <location filename="../../CommandExport.cpp" line="+50"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka compact subroutine...</source>
      <translation>Kuka kompakt eljárás ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Export the trajectory as a compact KRL subroutine.</source>
      <translation>Útvonal exportálása kompakt KRL eljárásként.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotExportKukaFull</name>
    <message>
      <location line="+63"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka full subroutine...</source>
      <translation>Kuka teljes eljárás ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Export the trajectory as a full KRL subroutine.</source>
      <translation>Útvonal exportálása teljes KRL eljárásként.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR125</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="-43"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka IR125</source>
      <translation>Kuka IR125</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert a Kuka IR125 into the document.</source>
      <translation>Helyezzen be egy Kuka IR210-et a dokumentumba.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR16</name>
    <message>
      <location line="-83"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka IR16</source>
      <translation>Kuka IR16</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert a Kuka IR16 into the document.</source>
      <translation>Helyezzen be egy Kuka IR210-et a dokumentumba.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR210</name>
    <message>
      <location line="+39"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka IR210</source>
      <translation>Kuka IR210</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert a Kuka IR210 into the document.</source>
      <translation>Helyezzen be egy Kuka IR16-ot a dokumentumba.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR500</name>
    <message>
      <location line="-85"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka IR500</source>
      <translation>Kuka IR500</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert a Kuka IR500 into the document.</source>
      <translation>Helyezzen be egy Kuka IR125-öt a dokumentumba.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertWaypoint</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="-228"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert in trajectory</source>
      <translation>Útvonal beszúrása</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert robot Tool location into trajectory</source>
      <translation>Robot szerszám elhelyezése az útvonalon</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertWaypointPreselect</name>
    <message>
      <location line="+55"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert in trajectory</source>
      <translation>Útvonal beszúrása</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert preselection position into trajectory (W)</source>
      <translation>Beállítási pozíció beszúrása az útvonalba (W)</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotRestoreHomePos</name>
    <message>
      <location filename="../../Command.cpp" line="-56"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Move to home</source>
      <translation>Alaphelyzetbe állít</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetDefaultOrientation</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="+62"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Set default orientation</source>
      <translation>Alapértelmezett hely beállítása</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set the default orientation for subsequent commands for waypoint creation</source>
      <translation>Alapértelmezett hely beállítása a későbbi szakaszpont parancsokhoz a várópontok létrehozásoknál</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetDefaultValues</name>
    <message>
      <location line="+37"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Set default values</source>
      <translation>Alapértelmezett értékek</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</source>
      <translation>Alapértelmezett sebesség, gyorsulás és folytonossági szakaszpont értékeinek beállítása</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetHomePos</name>
    <message>
      <location filename="../../Command.cpp" line="-51"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Set the home position</source>
      <translation>Alaphelyzet beállítása</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSimulate</name>
    <message>
      <location line="+142"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Simulate a trajectory</source>
      <translation>Útvonal szimuláció</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Run a simulation on a trajectory</source>
      <translation>Szimuláció futtaása az útvonalon</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotTrajectoryCompound</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="+175"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trajectory compound...</source>
      <translation>Pálya összetétel...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Group and connect some trajectories to one</source>
      <translation>Csoportosít és közössé tesz bizonyos pályákat</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotTrajectoryDressUp</name>
    <message>
      <location line="-49"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Dress up trajectory...</source>
      <translation>Útvonal felruházása...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a dress up object which overide som aspects of a trajectory</source>
      <translation>Hozzon létre egy felöltöztetett objektumot mely felülírja a pálya szempontjait</translation>
    </message>
  </context>
  <context>
    <name>Gui::TaskView::TaskWatcherCommands</name>
    <message>
      <location filename="../../Workbench.cpp" line="+52"/>
      <source>Trajectory tools</source>
      <translation>Trajektória eszközök</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Robot tools</source>
      <translation>Robot eszközök</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert Robot</source>
      <translation>Robotok beszúrása</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="-126"/>
      <location line="+49"/>
      <location line="+100"/>
      <location line="+29"/>
      <location filename="../../CommandExport.cpp" line="-52"/>
      <location line="+65"/>
      <location filename="../../CommandInsertRobot.cpp" line="+181"/>
      <location filename="../../CommandTrajectory.cpp" line="-276"/>
      <location line="+56"/>
      <location line="+17"/>
      <location line="+229"/>
      <source>Wrong selection</source>
      <translation>Rossz kiválasztás</translation>
    </message>
    <message>
      <location line="-28"/>
      <location line="+29"/>
      <location filename="../../CommandExport.cpp" line="-64"/>
      <location line="+65"/>
      <location filename="../../CommandTrajectory.cpp" line="-301"/>
      <source>Select one Robot and one Trajectory object.</source>
      <translation>Egy Robot és egy útvonal objektum kijelölése.</translation>
    </message>
    <message>
      <location line="-24"/>
      <source>Trajectory not valid</source>
      <translation>Érvénytelen útvonal</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>You need at least two way points in a trajectory to simulate.</source>
      <translation>A szimulációhoz legalább két útvonalpontra van szükség a pályán.</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="-43"/>
      <location line="+65"/>
      <source>KRL file(*.src)</source>
      <translation>KRL fájl (*.src)</translation>
    </message>
    <message>
      <location line="-64"/>
      <location line="+65"/>
      <source>All Files (*.*)</source>
      <translation>Minden fájl (*.*)</translation>
    </message>
    <message>
      <location line="-64"/>
      <location line="+65"/>
      <source>Export program</source>
      <translation>Program exportálása</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="+1"/>
      <source>Select one robot and one shape or VRML object.</source>
      <translation>Egy robot és egy alakzat vagy VRML objektum kijelölése.</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="+79"/>
      <source>No preselection</source>
      <translation>Nincs előzetes kijelölés</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</source>
      <translation>A geometria (előválasztás) fölé kell vinni az egérrel a kurzort, hogy használni tudja ezt a parancsot. Részleteket a dokumentációban talál.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-155"/>
      <source>Select one Robot to set home postion</source>
      <translation>Robot kiválasztása és alaphelyzetbe állítása</translation>
    </message>
    <message>
      <location line="+49"/>
      <source>Select one Robot</source>
      <translation>Válasszon ki egy robotot</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="-24"/>
      <location line="+17"/>
      <source>Select one Trajectory object.</source>
      <translation>Válasszon ki egy pálya objektumot.</translation>
    </message>
    <message>
      <location line="+84"/>
      <source>set default speed</source>
      <translation>alapértelmezett sebesség beállítása</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>speed: (e.g. 1 m/s or 3 cm/s)</source>
      <translation>sebesség: (pl. 1 m/s vagy 3 cm/s)</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>set default continuity</source>
      <translation>alapértelmezett folytonosság</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>continuous ?</source>
      <translation>folyamatos?</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>set default acceleration</source>
      <translation>alapértelmezett gyorsulás beállítás</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>acceleration: (e.g. 1 m/s^2 or 3 cm/s^2)</source>
      <translation>gyorsulás: (pl. 1 m/s^2 vagy 3 cm/s^2)</translation>
    </message>
    <message>
      <location line="+127"/>
      <source>Select the Trajectory which you want to dress up.</source>
      <translation>Válassza ki a Trayectory-t a felöltöztetéshez.</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="+26"/>
      <source>No robot files installed</source>
      <translation>Nincs telepített robot-fájl</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please visit %1 and copy the files to %2</source>
      <translation>Kérjük, látogasson el ide: %1 és másolja a fájlokat a következő helyre: %2</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::DlgTrajectorySimulate</name>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="+20"/>
      <source>Simulation</source>
      <translation>Szimuláció</translation>
    </message>
    <message>
      <location line="+38"/>
      <source>|&lt;</source>
      <translation>|&lt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&lt;</source>
      <translation>&lt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>||</source>
      <translation>||</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>|&gt;</source>
      <translation>|&gt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&gt;</source>
      <translation>&gt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&gt;|</source>
      <translation>&gt;|</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>%</source>
      <translation>%</translation>
    </message>
    <message>
      <location line="+35"/>
      <source>Type</source>
      <translation>Típus</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Name</source>
      <translation>Név</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>C</source>
      <translation>C</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>V</source>
      <translation>V</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>A</source>
      <translation>A</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskEdge2TracParameter</name>
    <message>
      <location filename="../../TaskEdge2TracParameter.cpp" line="+47"/>
      <source>TaskEdge2TracParameter</source>
      <translation>TaskEdge2TracParameter</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobot6Axis</name>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="+14"/>
      <source>Form</source>
      <translation>Űrlap</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>A1</source>
      <translation>A1</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A2</source>
      <translation>A2</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A3</source>
      <translation>A3</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A4</source>
      <translation>A4-es</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A5</source>
      <translation>A5</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A6</source>
      <translation>A6</translation>
    </message>
    <message>
      <location line="+57"/>
      <source>TCP: (200.23,300.23,400.23,234,343,343)</source>
      <translation>TCP: (200.23,300.23,400.23,234,343,343)</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Tool: (0,0,400,0,0,0)</source>
      <translation>Eszköz:(0,0,400,0,0,0)</translation>
    </message>
    <message>
      <location line="+16"/>
      <source>...</source>
      <translation>...</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.cpp" line="+52"/>
      <source>TaskRobot6Axis</source>
      <translation>TaskRobot6Axis</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobotControl</name>
    <message>
      <location filename="../../TaskRobotControl.cpp" line="+46"/>
      <source>TaskRobotControl</source>
      <translation>TaskRobotControl</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobotMessages</name>
    <message>
      <location filename="../../TaskRobotMessages.cpp" line="+46"/>
      <source>TaskRobotMessages</source>
      <translation>TaskRobotMessages</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskTrajectory</name>
    <message>
      <location filename="../../TaskTrajectory.ui" line="+20"/>
      <source>Form</source>
      <translation>Űrlap</translation>
    </message>
    <message>
      <location line="+38"/>
      <source>|&lt;</source>
      <translation>|&lt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&lt;</source>
      <translation>&lt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>||</source>
      <translation>||</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>|&gt;</source>
      <translation>|&gt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&gt;</source>
      <translation>&gt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&gt;|</source>
      <translation>&gt;|</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>%</source>
      <translation>%</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>10 ms</source>
      <translation>10 ms</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>50 ms</source>
      <translation>50 ms</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>100 ms</source>
      <translation>100 ms</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>500 ms</source>
      <translation>500 ms</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>1 s</source>
      <translation>1 s</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</source>
      <translation>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Type</source>
      <translation>Típus</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Name</source>
      <translation>Név</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>C</source>
      <translation>C</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>V</source>
      <translation>V</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>A</source>
      <translation>A</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.cpp" line="+44"/>
      <source>Trajectory</source>
      <translation>Pálya</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskTrajectoryDressUpParameter</name>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.cpp" line="+48"/>
      <source>Dress Up Parameter</source>
      <translation>Felruházási paraméter</translation>
    </message>
  </context>
  <context>
    <name>TaskEdge2TracParameter</name>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="+14"/>
      <source>Form</source>
      <translation>Űrlap</translation>
    </message>
    <message>
      <location line="+15"/>
      <source>Hide / Show</source>
      <translation>Elrejt/megjelenít</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Edges: 0</source>
      <translation>Élek: 0</translation>
    </message>
    <message>
      <location line="+14"/>
      <source>Cluster: 0</source>
      <translation>Fürt: 0</translation>
    </message>
    <message>
      <location line="+11"/>
      <source>Sizing Value:</source>
      <translation>Méret érték:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Use orientation of edge</source>
      <translation>Használja az él orientációját</translation>
    </message>
    <message>
      <source>TaskEdge2TracParameter</source>
      <translation type="obsolete">TaskEdge2TracParameter</translation>
    </message>
  </context>
  <context>
    <name>TaskRobot6Axis</name>
    <message>
      <source>TaskRobot6Axis</source>
      <translation type="obsolete">TaskRobot6Axis</translation>
    </message>
  </context>
  <context>
    <name>TaskRobotControl</name>
    <message>
      <location filename="../../TaskRobotControl.ui" line="+14"/>
      <source>Form</source>
      <translation>Űrlap</translation>
    </message>
    <message>
      <location line="+23"/>
      <source>X+</source>
      <translation>X+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>Y+</source>
      <translation>Y+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>Z+</source>
      <translation>Z+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>A+</source>
      <translation>A+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>B+</source>
      <translation>B+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>C+</source>
      <translation>C+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>X-</source>
      <translation>X-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>Y-</source>
      <translation>Y-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>Z-</source>
      <translation>Z-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>A-</source>
      <translation>A-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>B-</source>
      <translation>B-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>C-</source>
      <translation>C-</translation>
    </message>
    <message>
      <location line="+12"/>
      <source>Tool 0</source>
      <translation>Eszköz 0</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Tool</source>
      <translation>Eszköz</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Base 0</source>
      <translation>Alap 0</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Base</source>
      <translation>Alap</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>World</source>
      <translation>Világ</translation>
    </message>
    <message utf8="true">
      <location line="+9"/>
      <source>50mm / 5°</source>
      <translation>50mm / 5°</translation>
    </message>
    <message utf8="true">
      <location line="+5"/>
      <source>20mm / 2°</source>
      <translation>20mm / 2°</translation>
    </message>
    <message utf8="true">
      <location line="+5"/>
      <source>10mm / 1°</source>
      <translation>10mm / 1°</translation>
    </message>
    <message utf8="true">
      <location line="+5"/>
      <source>5mm / 0.5°</source>
      <translation>5mm / 0.5°</translation>
    </message>
    <message utf8="true">
      <location line="+5"/>
      <source>1mm / 0.1°</source>
      <translation>1mm / 0.1°</translation>
    </message>
    <message>
      <source>TaskRobotControl</source>
      <translation type="obsolete">TaskRobotControl</translation>
    </message>
  </context>
  <context>
    <name>TaskRobotMessages</name>
    <message>
      <location filename="../../TaskRobotMessages.ui" line="+14"/>
      <source>Form</source>
      <translation>Űrlap</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>clear</source>
      <translation>ürít</translation>
    </message>
    <message>
      <source>TaskRobotMessages</source>
      <translation type="obsolete">TaskRobotMessages</translation>
    </message>
  </context>
  <context>
    <name>TaskTrajectory</name>
    <message>
      <source>Trajectory</source>
      <translation type="obsolete">Pálya</translation>
    </message>
  </context>
  <context>
    <name>TaskTrajectoryDressUpParameter</name>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="+14"/>
      <source>Form</source>
      <translation>Űrlap</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Speed &amp; Acceleration:</source>
      <translation>Sebesség és gyorsulás:</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Speed:</source>
      <translation>Sebesség:</translation>
    </message>
    <message>
      <location line="+26"/>
      <location line="+37"/>
      <source>Use</source>
      <translation>Használ</translation>
    </message>
    <message>
      <location line="-26"/>
      <source>Accel:</source>
      <translation>Gyorsítás:</translation>
    </message>
    <message>
      <location line="+36"/>
      <source>Don't change Cont</source>
      <translation>Ne módosítsa a tartalmát</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Continues</source>
      <translation>Tovább</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Discontinues</source>
      <translation>Befejez</translation>
    </message>
    <message>
      <location line="+15"/>
      <source>Position and Orientation:</source>
      <translation>Helyzete és iránya:</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>(0,0,0),(0,0,0)</source>
      <translation>(0,0,0),(0,0,0)</translation>
    </message>
    <message>
      <location line="+13"/>
      <source>...</source>
      <translation>...</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Don't change Position &amp; Orientation</source>
      <translation>Ne módosítsa a pozíciót és a tájolást</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Use Orientation</source>
      <translation>Orientáció használata</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Add Position</source>
      <translation>Pozíció hozzáadása</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Add Orientation</source>
      <translation>Orientáció hozzáadása</translation>
    </message>
    <message>
      <source>Dress Up Parameter</source>
      <translation type="obsolete">Felruházási paraméter</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="-33"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert Robots</source>
      <translation>Robotok beszúrása</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Export trajectory</source>
      <translation>Pálya exportálása</translation>
    </message>
  </context>
</TS>
